ConfirmEmailVerificationUseCase class
Use case for verifying email address with verification token.
Constructors
- ConfirmEmailVerificationUseCase(AuthRepository repository)
-
Creates a ConfirmEmailVerificationUseCase instance.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- repository → AuthRepository
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{required String token}) → Future< void> - Executes email verification token confirmation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited