AuthRepositoryImpl class
Implementation of AuthRepository in the data layer connecting usecases to remote data source.
- Implemented types
Constructors
- AuthRepositoryImpl({required AuthRemoteDataSource remoteDataSource})
-
Creates an AuthRepositoryImpl.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- remoteDataSource → AuthRemoteDataSource
-
Remote data source instance.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
confirmEmailVerification(
{required String token}) → Future< void> -
Confirms email address verification using verification token.
override
-
confirmPasswordReset(
{required String token, required String password, required String passwordConfirm}) → Future< void> -
Confirms password reset using reset token and new password credentials.
override
-
login(
{required String email, required String password}) → Future< AuthResponseEntity> -
Authenticates user with email and password.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
RegisterRequestModel request) → Future< UserEntity> -
Registers a new user account with provided registration payload model.
override
-
requestPasswordReset(
{required String email}) → Future< void> -
Requests a password reset email for specified user email address.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited