RegisterRequestModel class
Data transfer model for user registration request payload.
Designed to be flexible, supporting clean registration attributes.
Constructors
-
RegisterRequestModel({required String email, required String name, required String password, required String passwordConfirm, Map<
String, dynamic> ? customData}) -
Creates a RegisterRequestModel instance.
const
-
RegisterRequestModel.fromJson(Map<
String, dynamic> json) -
Creates a RegisterRequestModel from a JSON map.
factory
Properties
-
customData
→ Map<
String, dynamic> ? -
Optional custom JSON key-value map for any app-specific user fields.
final
- email → String
-
Email address of the user.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Full display name of the user.
final
- password → String
-
User account password.
final
- passwordConfirm → String
-
Password confirmation string matching password.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts registration payload model into exact JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited